"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const url_1 = require("url");
function tryJsonParse(data) {
    try {
        return JSON.parse(data);
    }
    catch (e) {
        return data;
    }
}
exports.tryJsonParse = tryJsonParse;
class TimeoutError extends Error {
}
exports.TimeoutError = TimeoutError;
function waitFor(fn, timeout = 100) {
    const timeStart = Date.now();
    return new Promise((resolve, reject) => {
        const intervalId = setInterval(() => {
            if (fn()) {
                clearInterval(intervalId);
                return resolve();
            }
            else if (Date.now() - timeStart > timeout) {
                clearInterval(intervalId);
                return reject(new TimeoutError(`waitFor timeout - provided function did not return true in ${timeout}ms`));
            }
        });
    });
}
exports.waitFor = waitFor;
function printRequest(request) {
    return `type=${request.type} method=${request.method} url=${request.url}`;
}
exports.printRequest = printRequest;
function nth(d) {
    if (d > 3 && d < 21)
        return `${d}th`;
    switch (d % 10) {
        case 1:
            return `${d}st`;
        case 2:
            return `${d}nd`;
        case 3:
            return `${d}rd`;
        default:
            return `${d}th`;
    }
}
exports.nth = nth;
function addMockByPriority(mockArr, mock) {
    const index = mockArr.findIndex((item) => item.options.priority <= mock.options.priority);
    const calculatedIndex = index === -1 ? mockArr.length : index;
    mockArr.splice(calculatedIndex, 0, mock);
    return mockArr;
}
exports.addMockByPriority = addMockByPriority;
function createRequestMatcher(input, method) {
    if (typeof input === 'string') {
        return {
            method,
            url: input,
        };
    }
    else {
        return Object.assign({ method }, input);
    }
}
exports.createRequestMatcher = createRequestMatcher;
function getCorsHeaders(request) {
    const requestHeaders = request.headers;
    const origin = request.sourceOrigin;
    const headers = {
        'Access-Control-Allow-Origin': origin,
        'Access-Control-Allow-Credentials': 'true',
        'Access-Control-Allow-Methods': requestHeaders['access-control-request-method'],
        'Access-Control-Allow-Headers': requestHeaders['access-control-request-headers'],
    };
    return headers;
}
exports.getCorsHeaders = getCorsHeaders;
/**
 * Sanitize headers object from empty or null values
 * because they make request hang indefinitely in puppeteer
 */
function sanitizeHeaders(headers) {
    return Object.keys(headers).reduce((acc, key) => {
        if (Boolean(headers[key])) {
            acc[key] = headers[key];
        }
        return acc;
    }, {});
}
exports.sanitizeHeaders = sanitizeHeaders;
function printResponse(status, headers, body) {
    const headersStr = JSON.stringify(headers);
    const bodyStr = body.toString('utf8');
    return `status=${status} headers=${headersStr} body=${bodyStr}`;
}
exports.printResponse = printResponse;
function getOrigin(originUrl) {
    const { protocol, host } = url_1.parse(originUrl !== null && originUrl !== void 0 ? originUrl : '');
    if (protocol && host) {
        return `${protocol}//${host}`;
    }
    return '';
}
exports.getOrigin = getOrigin;
//# sourceMappingURL=utils.js.map